<!doctype html>
<html>

  <head>
    <meta charset="utf-8" />
    <meta name="keywords" content="cicero,markdown,slideshow,presentation" />
    <meta name="description" content="cicero.xyz: serving slides written in markdown." />
    <link rel="icon" type="image/png" href="{{ url_for('static', filename='img/icon.png') }}" />
    <title>{{ title }}</title>
    <link rel="stylesheet" href="{{ url_for('static', filename='engines/' + engine + '/vendor.css') }}">

    <style>
      {{ own_css }}
    </style>
  </head>

  <body>
    {% include 'engines/' + engine + '/body.html' %}

    <script src="{{ url_for('static', filename='engines/' + engine + '/vendor.js') }}" type="text/javascript">
    </script>

    {% include 'engines/' + engine + '/js.html' %}
  </body>

</html>
