@import url(https://fonts.googleapis.com/css?family=Droid+Serif);
@import url(https://fonts.googleapis.com/css?family=Yanone+Kaffeesatz);
@import url(https://fonts.googleapis.com/css?family=Ubuntu+Mono:400,700,400italic);

body {
  font-family: 'Droid Serif';
}
h1, h2, h3 {
  font-family: 'Yanone Kaffeesatz';
  font-weight: 400;
  margin-bottom: 0;
}
.remark-slide-content h1 { font-size: 3em; }
.remark-slide-content h2 { font-size: 2em; }
.remark-slide-content h3 { font-size: 1.6em; }
.footnote {
  position: absolute;
  bottom: 3em;
}
li p { line-height: 1.25em; }
.red { color: #fa0000; }
.large { font-size: 2em; }
a, a > code {
  color: rgb(249, 38, 114);
  text-decoration: none;
}
code {
  background: #e7e8e2;
  border-radius: 5px;
}
.remark-code, .remark-inline-code { font-family: 'Ubuntu Mono'; }
.remark-code-line-highlighted     { background-color: #373832; }
.pull-left {
  float: left;
  width: 47%;
}
.pull-right {
  float: right;
  width: 47%;
}
.pull-right ~ p {
  clear: both;
}
#slideshow .slide .content code {
  font-size: 0.8em;
}
#slideshow .slide .content pre code {
  font-size: 0.9em;
  padding: 15px;
}
.inverse {
  background: #272822;
  color: #777872;
  text-shadow: 0 0 20px #333;
}
.inverse h1, .inverse h2 {
  color: #f3f3f3;
  line-height: 0.8em;
}
/* Slide-specific styling */
#slide-inverse .footnote {
  bottom: 12px;
  left: 20px;
}
#slide-how .slides {
  font-size: 0.9em;
  position: absolute;
  top:  151px;
  right: 140px;
}
#slide-how .slides h3 {
  margin-top: 0.2em;
}
#slide-how .slides .first, #slide-how .slides .second {
  padding: 1px 20px;
  height: 90px;
  width: 120px;
  -moz-box-shadow: 0 0 10px #777;
  -webkit-box-shadow: 0 0 10px #777;
  box-shadow: 0 0 10px #777;
}
#slide-how .slides .first {
  background: #fff;
  position: absolute;
  top: 20%;
  left: 20%;
  z-index: 1;
}
#slide-how .slides .second {
  position: relative;
  background: #fff;
  z-index: 0;
}
/* Two-column layout */
.left-column {
  color: #777;
  width: 20%;
  height: 92%;
  float: left;
}
  .left-column h2:last-of-type, .left-column h3:last-child {
    color: #000;
  }
.right-column {
  width: 75%;
  float: right;
  padding-top: 1em;
}

.blue {
    color: #0000ff;
}

/* two-column layout with different splits */
.column:first-of-type {
    float: left;
}
.column:last-of-type {
    float: right;
}
.split-30-70 .column:first-of-type {
    width: 30%;
}
.split-30-70 .column:last-of-type {
    width: 70%;
}
.split-40-60 .column:first-of-type {
    width: 40%;
}
.split-40-60 .column:last-of-type {
    width: 60%;
}
.split-50-50 .column:first-of-type {
    width: 50%;
}
.split-50-50 .column:last-of-type {
    width: 50%;
}
.split-60-40 .column:first-of-type {
    width: 60%;
}
.split-60-40 .column:last-of-type {
    width: 40%;
}
.split-70-30 .column:first-of-type {
    width: 70%;
}
.split-70-30 .column:last-of-type {
    width: 30%;
}


/* some special classes */
.title {
    font-size: 3.3em;
    color: #606060;
    font-weight: bold;
    letter-spacing: 0.05em;
}
.subtitle {
    font-size: 1.4em;
}
.author {
    font-size: 1.4em;
    color: #606060;
    font-weight: bold;
    letter-spacing: 0.02em;
}
.coauthor {
    font-size: 1.0em;
    color: #606060;
    font-weight: bold;
    letter-spacing: 0.02em;
}
.institution {
    font-size: 1.0em;
}
.date {
    font-size: 1.0em;
    font-style: italic;
}
.cite {
    font-size: 0.8em;
    color: #33AA99;
    font-style: italic;
}
.strike {
    color: salmon;
    text-decoration: line-through;
}
.footnote-cite {
    position: absolute;
    bottom: 3em;
    color: #7f7f7f;
    font-size: 0.8em;
}


/* images overlay */
.imageWrapper {
    position: relative;
}
.overlayImage {
    position: absolute;
    top: 0;
    left: 0;
}
