<!doctype html>
<html lang="en" ng-app="app">
  <head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">

    <link rel="icon"
          type="image/png"
          href="{{ url_for('static', filename='img/icon.png') }}" />

    <title>{% block page_title %}Cicero - Serving presentation slides written in Markdown{% endblock %}</title>

    <link rel="stylesheet" href="{{ url_for('static', filename='bootstrap/bootstrap-4.1.3.min.css') }}">

    <link href='//fonts.googleapis.com/css?family=Open+Sans:300' rel='stylesheet' type='text/css'>

    <style>
      body {
        font-family: 'Open Sans';
        font-size: 16px;
      }

      input[type="text"], textarea {
        background-color: #99eeff;
      }

      .top-buffer { margin-top: 35px; }

      /* https://vuejs.org/v2/api/#v-cloak */
      [v-cloak] {
        display: none;
      }
    </style>

  </head>
  <body ng-controller="Ctrl">
    {% block content %}
    {% endblock %}

    <script src="{{ url_for('static', filename='bootstrap/jquery-3.3.1.slim.min.js') }}"></script>
    <script src="{{ url_for('static', filename='bootstrap/popper-1.14.3.min.js') }}"></script>
    <script src="{{ url_for('static', filename='bootstrap/bootstrap-4.1.3.min.js') }}"></script>

    <script src="https://cdn.jsdelivr.net/npm/axios@0.12.0/dist/axios.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/lodash@4.13.1/lodash.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/vue@2.5.16/dist/vue.min.js"></script>

    <script src="{{ url_for('static', filename='search/app.js') }}"></script>

  </body>
</html>
