{% extends "base.html" %}

{% block title %}Page Not Found{% endblock %}

{% block content %}
<div class="container">
  <div class="col-md-12">
    <div class="row">
      <h1>Page Not Found</h1>
      What you were looking for is just not there. Go somewhere
      <a href="{{ url_for('git.home') }}">nice</a>.
    </div>
  </div>
</div>
{% endblock %}
